==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/sq/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Statusi <strong>Cronjob</strong>',
    '<strong>Queue</strong> Status' => 'Statusi <strong>Queue</strong>',
    'About HumHub' => 'Rreth HumHub',
    'Background Jobs' => 'Punët në prapaskenë',
    'Checking HumHub software prerequisites.' => 'Kontrollimi i parakushteve të softuerit HumHub.',
    'Database' => 'Baza e të dhënave',
    'Database migration results:' => 'Rezultati i migrimit të bazës së të dhënave',
    'Delayed' => 'I vonuar',
    'Displaying {count} entries per page.' => 'Duke shfaqur {count} hyrje për faqe.',
    'Done' => 'E kryer',
    'Driver' => 'Driver',
    'Error' => 'Gabim',
    'Flush entries' => 'Hyrjet e ndezura',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub është momentalisht në mundësinë e korigjimit (debug mode). Çaktivizojeni kur uebsajti futet në funksion!',
    'Info' => 'Informata',
    'Last run (daily):' => 'Aktivizimi i fundit (ditorë):',
    'Last run (hourly):' => 'Aktivizimi i fundit (çdo orë)',
    'Licences' => 'Licensat',
    'Logging' => 'Logging',
    'Never' => 'Kurrë',
    'Other' => 'Tjera',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Ju lutemi referojuni dokumentacionit për të konfiguruar cronjobs dhe queue.',
    'Prerequisites' => 'Parakushtet',
    'Queue successfully cleared.' => 'Queue është pastruar me sukses.',
    'Re-Run tests' => 'Riaktivizo testet',
    'Reserved' => 'E rezervuar',
    'Search index rebuild in progress.' => 'Rindërtimi i indeksit të kërkimit në progres.',
    'Search term...' => 'Kërko termin...',
    'See installation manual for more details.' => 'Shikoni manualin e instalimit për më tepër detaje.',
    'Select category..' => 'Selekto kategorinë',
    'Select day' => 'Selekto ditën',
    'Select level...' => 'Selekto nivelin...',
    'The current main HumHub database name is ' => 'Emri i tanishëm i bazës së të dhënave të HumHub është',
    'There is a new update available! (Latest version: %version%)' => 'Ka një përditësim të ri! (Vezioni i fundit: (%version%)',
    'This HumHub installation is up to date!' => 'Ky instalim i HumHub është i përditësuar!',
    'Total {count} entries found.' => 'Total {count} hyrje u gjetën.',
    'Trace' => 'Gjurmo',
    'Waiting' => 'Duke pritur',
    'Warning' => 'Paralajmërim',
    'Assets' => '',
    'Base URL' => '',
    'Current limit is: {currentLimit}' => '',
    'Database collation' => '',
    'Database connection time: {dbTime} - Configured time zone: {time}' => '',
    'Database driver - {driver}' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for DB Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Optional' => '',
    'Permissions' => '',
    'Profile Image' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Runtime' => '',
    'Settings' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'Time zone' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/admin/messages/sq/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Statusi <strong>Cronjob</strong>',
    '<strong>Queue</strong> Status' => 'Statusi <strong>Queue</strong>',
    'About HumHub' => 'Rreth HumHub',
    'Background Jobs' => 'Punët në prapaskenë',
    'Checking HumHub software prerequisites.' => 'Kontrollimi i parakushteve të softuerit HumHub.',
    'Database' => 'Baza e të dhënave',
    'Database migration results:' => 'Rezultati i migrimit të bazës së të dhënave',
    'Delayed' => 'I vonuar',
    'Displaying {count} entries per page.' => 'Duke shfaqur {count} hyrje për faqe.',
    'Done' => 'E kryer',
    'Driver' => 'Driver',
    'Error' => 'Gabim',
    'Flush entries' => 'Hyrjet e ndezura',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub është momentalisht në mundësinë e korigjimit (debug mode). Çaktivizojeni kur uebsajti futet në funksion!',
    'Info' => 'Informata',
    'Last run (daily):' => 'Aktivizimi i fundit (ditorë):',
    'Last run (hourly):' => 'Aktivizimi i fundit (çdo orë)',
    'Licences' => 'Licensat',
    'Logging' => 'Logging',
    'Never' => 'Kurrë',
    'Other' => 'Tjera',
    'Permissions' => 'Lejet',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Ju lutemi referojuni dokumentacionit për të konfiguruar cronjobs dhe queue.',
    'Prerequisites' => 'Parakushtet',
    'Queue successfully cleared.' => 'Queue është pastruar me sukses.',
    'Re-Run tests' => 'Riaktivizo testet',
    'Reserved' => 'E rezervuar',
    'Search index rebuild in progress.' => 'Rindërtimi i indeksit të kërkimit në progres.',
    'Search term...' => 'Kërko termin...',
    'See installation manual for more details.' => 'Shikoni manualin e instalimit për më tepër detaje.',
    'Select category..' => 'Selekto kategorinë',
    'Select day' => 'Selekto ditën',
    'Select level...' => 'Selekto nivelin...',
    'Settings' => 'Cilësimet',
    'The current main HumHub database name is ' => 'Emri i tanishëm i bazës së të dhënave të HumHub është',
    'There is a new update available! (Latest version: %version%)' => 'Ka një përditësim të ri! (Vezioni i fundit: (%version%)',
    'This HumHub installation is up to date!' => 'Ky instalim i HumHub është i përditësuar!',
    'Total {count} entries found.' => 'Total {count} hyrje u gjetën.',
    'Trace' => 'Gjurmo',
    'Waiting' => 'Duke pritur',
    'Warning' => 'Paralajmërim',
    'Assets' => '',
    'Base URL' => '',
    'Current limit is: {currentLimit}' => '',
    'Database collation' => '',
    'Database connection time: {dbTime} - Configured time zone: {time}' => '',
    'Database driver - {driver}' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'Disabled Functions' => '',
    'Dynamic Config' => '',
    'HumHub' => '',
    'HumHub Documentation' => '',
    'ICU Data Version ({version})' => '',
    'ICU Data {icuMinVersion} or higher is required' => '',
    'ICU Version ({version})' => '',
    'ICU {icuMinVersion} or higher is required' => '',
    'Increase memory limit in {fileName}' => '',
    'Install {phpExtension} Extension' => '',
    'Install {phpExtension} Extension for APC Caching' => '',
    'Install {phpExtension} Extension for DB Caching' => '',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Make {filePath} writable for the Webserver/PHP!' => '',
    'Marketplace API Connection' => '',
    'Memory Limit ({memoryLimit})' => '',
    'Minimum Version {minVersion}' => '',
    'Module Directory' => '',
    'Multibyte String Functions' => '',
    'Optional' => '',
    'Pretty URLs' => '',
    'Profile Image' => '',
    'Recommended collation is {collation}' => '',
    'Recommended collation is {collation} for the tables: {tables}' => '',
    'Recommended engine is {engine} for the tables: {tables}' => '',
    'Runtime' => '',
    'Supported drivers: {drivers}' => '',
    'Table collations' => '',
    'Table engines' => '',
    'Time zone' => '',
    'Uploads' => '',
    'Varying table engines are not supported.' => '',
    'Version' => '',
    '{imageExtension} Support' => '',
    '{phpExtension} Extension' => '',
    '{phpExtension} Support' => '',
];
